@@ -31,16 +31,10 @@ cd ${DEB_SRC_DIR}
 
 # This is the real reason for repack: the license is non-dfsg
 rm -rf info
-# However, while we are repacking fix some things along the way:
-# the sources included some byte-compiled file by mistake
-find . -name "*.elc" -delete
-find . -name "*.pyc" -delete
-find . -name "*.pyo" -delete
+# Remove accidental backup files
+find . -name "*~" -delete
 # patches are already applied and don't need to go in
 rm -rf lisp/g-client/patches
-# documentation is generated, make sure we don't use the shipped stuff
-rm -rf servers/python/doc
-rm -rf servers/python/httpspeaker-html
 
 cd ..
 tar -acf ${DEB_SRC_TAR} ${DEB_SRC_DIR}
